package cn.estsh.i3plus.pojo.wms.bean;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.*;

/**
 * @Description : 库存移动单明细信息
 * @Reference :
 * @Author : silliter.yuan
 * @CreateDate : 2018-11-06 15:58
 * @Modify:
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="WMS_MOVE_DETAILS", indexes = {
        @Index(columnList = "PART_NO"),
        @Index(columnList = "ORDER_NO"),
        @Index(columnList = "ORGANIZE_CODE")
})
@Api("库存移动单明细信息")
public class WmsMoveDetails extends BaseBean {

    @Column(name="ORDER_NO")
    @ApiParam("单号")
    public String orderNo;

    @Column(name="ITEM")
    @ApiParam(value = "行号", example = "0")
    public Integer item;

    @Column(name="PART_NO")
    @ApiParam("物料编码")
    public String partNo;

    @Column(name="PART_NAME_RDD")
    @ApiParam("物料名称")
    public String partNameRdd;

    @Column(name="VENDOR_NO")
    @ApiParam("供应商编号")
    public String vendorNo;

    @Column(name="CUST_NO")
    @ApiParam("客户编号")
    public String custNo;

    @Column(name="TRANS_QTY")
    @ApiParam(value = "处理数量", example = "0")
    public Double transQty;

    public Double getTransQty(){
        return this.transQty == null ? 0 : this.transQty.doubleValue();
    }

    @Column(name="REJECT_QTY")
    @ApiParam(value = "不合格处理数量", example = "0")
    public Double rejectQty;

    public Double getRejectQty(){
        return this.rejectQty == null ? 0 : this.rejectQty.doubleValue();
    }

    @Column(name="UNIT")
    @ApiParam("单位")
    public String unit;

    @Column(name="SRC_WH_NO")
    @ApiParam("源仓库代码")
    public String srcWhNo;

    @Column(name="SRC_ZONE_NO")
    @ApiParam("源存储区代码")
    public String srcZoneNo;

    @Column(name="SRC_LOCATE_NO")
    @ApiParam("源库位代码")
    public String srcLocateNo;

    @Column(name="DEST_WH_NO")
    @ApiParam("目标仓库代码")
    public String destWhNo;

    @Column(name="DEST_ZONE_NO")
    @ApiParam("目标存储区代码")
    public String destZoneNo;

    @Column(name="DEST_LOCATE_NO")
    @ApiParam("目标库位代码")
    public String destLocateNo;

    /**
     * 状态:1=创建,10=待处理,20=已处理
     */
    @Column(name="ITEM_STATUS")
    @ApiParam(value = "状态", example = "0")
    public Integer itemStatus;

    @Column(name="REF_ITEM")
    @ApiParam("关联单据行号")
    public String refItem;

    /**
     * ASN,PO,SO
     */
    @Column(name="REF_TYPE")
    @ApiParam("关联单据类型")
    public String refType;

    @Column(name="REF_SRC")
    @ApiParam("关联单号")
    public String refSrc;

    @ApiParam(value = "待出库数量", example = "0")
    @Transient
    private Long waitingCounts;

    @ApiParam(value = "已出库数量", example = "0")
    @Transient
    private Long finishedCounts;

    @Transient
    @ApiParam("交易类型")
    private String transTypeCode;

    @Transient
    @ApiParam("erp库存地")
    private String ZoneNo;

    @Transient
    @ApiParam("条码")
    private String sn;

    public WmsMoveDetails(){}

    public WmsMoveDetails(String partNo, Long waitingCounts ,Long finishedCounts){
        this.partNo = partNo;
        this.waitingCounts = waitingCounts;
        this.finishedCounts = finishedCounts;
    }

    public WmsMoveDetails(String partNo, double transQty){
        this.partNo = partNo;
        this.transQty = transQty;
    }

    public WmsMoveDetails(String orderNo){
        this.orderNo = orderNo;
    }

    public Long getWaitingCounts() {
        return waitingCounts == null ? 0L : this.waitingCounts;
    }

    public Long getFinishedCounts() {
        return finishedCounts == null ? 0L : this.finishedCounts;
    }

    public WmsMoveDetails(String organizeCode,String orderNo,Integer item,String partNo,String partNameRdd,String transTypeCode,
                          Integer itemStatus,String unit,String srcWhNo,
                          String srcZoneNo,String srcLocateNo,String destWhNo, String destZoneNo, String destLocateNo,
                          Double transQty,Double rejectQty,String refSrc,String vendorNo, String custNo){
        this.organizeCode = organizeCode;
        this.partNo = partNo;
        this.orderNo = orderNo;
        this.item = item;
        this.partNameRdd = partNameRdd;
        this.transTypeCode = transTypeCode;
        this.itemStatus = itemStatus;
        this.unit = unit;
        this.srcWhNo = srcWhNo;
        this.srcZoneNo = srcZoneNo;
        this.srcLocateNo = srcLocateNo;
        this.destWhNo = destWhNo;
        this.destZoneNo = destZoneNo;
        this.destLocateNo = destLocateNo;
        this.transQty = transQty;
        this.rejectQty = rejectQty;
        this.refSrc = refSrc;
        this.vendorNo = vendorNo;
        this.custNo = custNo;



    }
}
